@@ -3,7 +3,7 @@ use strict;
 use DBI;
 
 use vars qw($VERSION);
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 =head1 NAME
 
@@ -15,7 +15,6 @@ DBIx::RunSQL - run SQL from a file
 
     #!/usr/bin/perl -w
     use strict;
-    use lib 'lib';
     use DBIx::RunSQL;
 
     my $test_dbh = DBIx::RunSQL->create(
@@ -283,7 +282,7 @@ sub run_sql {
                     my $res = $self->format_results( sth => $sth, no_header_when_empty => 1, %args );
                     print $res;
                     $errors = length $res > 0;
-                    
+
                 } elsif( $args{ output_string }) {
                     local $self->{formatter} = 'tab';
                     print $self->format_results( sth => $sth, headers => 0, %args );
@@ -306,32 +305,34 @@ sub parse_command_line {
 
     local @ARGV = @argv;
     if (GetOptions(
-        'user:s' => \my $user,
+        'user:s'     => \my $user,
         'password:s' => \my $password,
-        'dsn:s' => \my $dsn,
-        'verbose' => \my $verbose,
-        'force|f' => \my $force,
-        'sql:s' => \my $sql,
-        'bool' => \my $output_bool,
-        'string' => \my $output_string,
-        'help|h' => \my $help,
-        'man' => \my $man,
+        'dsn:s'      => \my $dsn,
+        'verbose'    => \my $verbose,
+        'force|f'    => \my $force,
+        'sql:s'      => \my $sql,
+        'bool'       => \my $output_bool,
+        'string'     => \my $output_string,
+        'format:s'   => \my $formatter_class,
+        'help|h'     => \my $help,
+        'man'        => \my $man,
     )) {
         no warnings 'newline';
         if( $sql and ! -f $sql ) {
             $sql = \"$sql",
         };
         return {
-        user     => $user,
-        password => $password,
-        dsn      => $dsn,
-        verbose  => $verbose,
-        force    => $force,
-        sql      => $sql,
-        output_bool => $output_bool,
+        user          => $user,
+        password      => $password,
+        dsn           => $dsn,
+        verbose       => $verbose,
+        force         => $force,
+        sql           => $sql,
+        output_bool   => $output_bool,
         output_string => $output_string,
-        help     => $help,
-        man      => $man,
+        formatter     => $formatter_class,
+        help          => $help,
+        man           => $man,
         };
     } else {
         return undef;
@@ -392,7 +393,7 @@ sub format_results {
     my( $self, %options )= @_;
     my $sth= delete $options{ sth };
 
-    if( ! exists $options{ formatter }) {
+    if( ! $options{ formatter }) {
         if( eval { require "Text/Table.pm" }) {
             $options{ formatter }= 'Text::Table';
         } else {
@@ -415,7 +416,7 @@ sub format_results {
                           $print_header ? join( "\t", @columns ) : (),
                           map { join( "\t", @$_ ) } @$res
                       ;
-            
+
         } else {
             my $t= $options{formatter}->new(@columns);
             $t->load( @$res );
@@ -502,11 +503,17 @@ looks like this:
 
     create-db.pl - Create the database
 
+    =head1 SYNOPSIS
+
+      create-db.pl "select * from mytable where 1=0"
+
     =head1 ABSTRACT
 
     This sets up the database. The following
     options are recognized:
 
+    =head1 OPTIONS
+
     =over 4
 
     =item C<--user> USERNAME
@@ -531,6 +538,8 @@ looks like this:
 
     Show this message.
 
+    =back
+
     =cut
 
 =head2 C<< DBIx::RunSQL->handle_command_line >>
@@ -542,6 +551,7 @@ passes the following command line arguments to C<< ->create >>:
   --password
   --dsn
   --sql
+  --format
   --force
   --verbose
 
@@ -611,7 +621,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2009-2016 by Max Maischein C<corion@cpan.org>.
+Copyright 2009-2017 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
